@@ -74,13 +74,16 @@ from OUT.  Note that for some cipher modes, IN and OUT may be different."))
     encrypted-message))
 
 (defun increment-counter-block (block)
+  (declare (type simple-octet-vector block))
   (let ((length (length block))
         (carry 1))
-    (loop for i from (1- length) downto 0
+    (declare (type fixnum length)
+             (type (unsigned-byte 16) carry))
+    (loop for i of-type fixnum from (1- length) downto 0
+          for sum of-type (unsigned-byte 16) = (+ (aref block i) carry)
           until (zerop carry) do
-          (let ((sum (+ (aref block i) carry)))
-            (setf (aref block i) (ldb (byte 8 0) sum)
-                  carry (ldb (byte 1 8) sum))))
+          (setf (aref block i) (ldb (byte 8 0) sum)
+                carry (ldb (byte 1 8) sum)))
     (values)))
 
 ;;; Only really works on big-endian processors...
@@ -95,10 +98,13 @@ from OUT.  Note that for some cipher modes, IN and OUT may be different."))
               (sb-bignum:%add-with-carry word 0 carry))
             (setf (sb-kernel:%vector-raw-bits block i) word)))
     (values)))
-          
+
 ;;; This way is kind of ugly, but I don't know a better way.
 (macrolet ((define-mode-function (&rest mode-definition-funs &environment env)
              (loop for fun in mode-definition-funs
+                   collect (macroexpand `(,fun 128-byte-block-mixin 128) env) into forms
+                   collect (macroexpand `(,fun 64-byte-block-mixin 64) env) into forms
+                   collect (macroexpand `(,fun 32-byte-block-mixin 32) env) into forms
                    collect (macroexpand `(,fun 16-byte-block-mixin 16) env) into forms
                    collect (macroexpand `(,fun 8-byte-block-mixin 8) env) into forms
                    finally (return `(progn ,@forms))))
@@ -334,17 +340,49 @@ from OUT.  Note that for some cipher modes, IN and OUT may be different."))
                   (flet ((ctr-crypt-function (function)
                            (declare (type function function))
                            (mode-lambda
-                            (loop for i of-type index from in-start below in-end
-                                  for j of-type index from out-start
-                                  do (when (zerop iv-position)
-                                       (funcall function cipher iv 0 encrypted-iv 0)
-                                       (increment-counter-block iv))
-                                     (setf (aref out j) (logxor (aref in i)
-                                                                (aref encrypted-iv iv-position)))
-                                     (setf iv-position (mod (1+ iv-position) ,block-length-expr))
-                                  finally (return
-                                            (let ((n-bytes-processed (- in-end in-start)))
-                                              (values n-bytes-processed n-bytes-processed)))))))
+                            (let ((remaining (- in-end in-start))
+                                  (processed 0))
+                              (declare (type index remaining processed))
+
+                              ;; Use remaining bytes in encrypted-iv
+                              (loop until (or (zerop remaining) (zerop iv-position))
+                                    do (setf (aref out (+ out-start processed))
+                                             (logxor (aref in (+ in-start processed))
+                                                     (aref encrypted-iv iv-position)))
+                                       (if (= iv-position (1- ,block-length-expr))
+                                           (setf iv-position 0)
+                                           (incf iv-position))
+                                       (incf processed)
+                                       (decf remaining))
+
+                              ;; Process data by block
+                              (loop until (< remaining ,block-length-expr)
+                                    do (funcall function cipher iv 0 encrypted-iv 0)
+                                       (increment-counter-block iv)
+                                       (xor-block ,block-length-expr
+                                                  encrypted-iv
+                                                  in
+                                                  (+ in-start processed)
+                                                  out
+                                                  (+ out-start processed))
+                                       (incf processed ,block-length-expr)
+                                       (decf remaining ,block-length-expr))
+
+                              ;; Process remaing bytes of data
+                              (loop until (zerop remaining)
+                                    do (when (zerop iv-position)
+                                         (funcall function cipher iv 0 encrypted-iv 0)
+                                         (increment-counter-block iv))
+                                       (setf (aref out (+ out-start processed))
+                                             (logxor (aref in (+ in-start processed))
+                                                     (aref encrypted-iv iv-position)))
+                                       (if (= iv-position (1- ,block-length-expr))
+                                           (setf iv-position 0)
+                                           (incf iv-position))
+                                       (incf processed)
+                                       (decf remaining))
+
+                              (values processed processed)))))
                     (let ((f (ctr-crypt-function (encrypt-function cipher))))
                       (values f f))))))
            (message-length (cipher-specializer block-length-expr)
