@@ -19,6 +19,10 @@
    #:make-hmac #:update-hmac #:hmac-digest
    ;; CMACs
    #:make-cmac #:update-cmac #:cmac-digest
+   ;; Skein-MAC
+   #:make-skein-mac #:update-skein-mac #:skein-mac-digest
+   ;; Poly1305
+   #:make-poly1305 #:update-poly1305 #:poly1305-digest
 
    ;; introspection
    #:cipher-supported-p #:list-all-ciphers
@@ -42,16 +46,18 @@
    #:pbkdf2-check-password
 
    ;; public-key encryption operations
-   #:make-public-key #:make-private-key
+   #:make-public-key #:make-private-key #:generate-key-pair
    #:sign-message #:verify-signature
    #:encrypt-message #:decrypt-message
 
-   ;; signatures
-   #:make-dsa-signature
+   ;; public-key encryption/signature padding
+   #:oaep-encode #:oaep-decode #:pss-encode #:pss-verify
 
    ;; public-key slot readers
    #:dsa-key-p #:dsa-key-q #:dsa-key-g #:dsa-key-y #:dsa-key-x
-   #:dsa-signature-r #:dsa-signature-s
+   #:elgamal-key-p #:elgamal-key-g #:elgamal-key-y #:elgamal-key-x
+   #:rsa-key-modulus #:rsa-key-exponent
+   #:ed25519-key-x #:ed25519-key-y
 
    ;; pseudo-random number generators
    #:pseudo-random-number-generator #:list-all-prngs #:make-prng #:random-data
@@ -60,6 +66,7 @@
 
    ;; cryptographic math
    #:generate-prime #:prime-p #:generate-prime-in-range #:egcd
+   #:generate-safe-prime #:find-generator
 
    ;; conditions
    #:ironclad-error #:initialization-vector-not-supplied
@@ -72,7 +79,7 @@
    ;; utilities
    #:byte-array-to-hex-string #:hex-string-to-byte-array
    #:ascii-string-to-byte-array
-   #:octets-to-integer #:integer-to-octets #:expt-mod
+   #:octets-to-integer #:integer-to-octets #:expt-mod #:expt-mod/unsafe
 
    ;; streams
    #:make-octet-input-stream #:make-octet-output-stream
@@ -85,10 +92,20 @@
   ;; supported digests
   (:export #:whirlpool #:md2 #:md4 #:md5 #:adler32 #:crc24 #:crc32
            #:tiger #:sha1 #:sha224 #:sha256 #:sha384 #:sha512
-           #:tree-hash #:make-tiger-tree-hash #:ripemd-128 #:ripemd-160)
+           #:tree-hash #:make-tiger-tree-hash #:ripemd-128 #:ripemd-160
+           #:skein256 #:skein256/128 #:skein256/160 #:skein256/224
+           #:skein512 #:skein512/128 #:skein512/160 #:skein512/224
+           #:skein512/256 #:skein512/384
+           #:skein1024 #:skein1024/384 #:skein1024/512
+           #:sha3 #:sha3/384 #:sha3/256 #:sha3/224
+           #:shake128 #:shake256
+           #:blake2 #:blake2/384 #:blake2/256 #:blake2/160
+           #:blake2s #:blake2s/224 #:blake2s/160 #:blake2s/128)
   ;; supported block ciphers
   (:export #:blowfish #:tea #:xtea #:square #:rc2 #:rc5 #:rc6 #:des #:3des
-           #:aes #:twofish #:cast5 #:idea #:misty1 #:null)
+           #:aes #:twofish #:cast5 #:idea #:misty1 #:null
+           #:threefish256 #:threefish512 #:threefish1024
+           #:serpent)
   ;; supported stream ciphers
   (:export #:arcfour #:salsa20 #:salsa20/12 #:salsa20/8
            #:chacha #:chacha/12 #:chacha/8))
